@@ -40,13 +40,13 @@ class Users(object):
 	):
 		try:
 			user, variable = None, None
-			if uid != None:
+			if uid not in [None, "None", ""]:
 				user = auth.get_user(uid)
 				variable = str(uid)
-			elif email != None:
+			elif email not in [None, "None", ""]:
 				user = auth.get_user_by_email(email)
 				variable = str(email)
-			elif phone_number != None:
+			elif phone_number not in [None, "None", ""]:
 				user = auth.get_user_by_phone_number(phone_number)
 				variable = str(phone_number)
 			else:
